@@ -67,24 +67,9 @@ as.SpatialPolygonsDataFrame <- function(x, ...) {
 }
 
 as.SpatialPolygonsDataFrame.geojson_file <- function(x, ...) {
-    readOGR(x$path, rgdal::ogrListLayers(x$path)[1], ...)
+  sf::st_read(x$path, quiet = TRUE, ...)
 }
 
 as.SpatialPolygonsDataFrame.character <- function(x, ...) {
-    readOGR(x, rgdal::ogrListLayers(x)[1], ...)
+  sf::st_read(x, quiet = TRUE, ...)
 }
-
-
-
-## SpatialRings to SpatialPoints
-# as.SpatialPoints.SpatialRings <- function(from) {
-#   rings <- slot(from, "rings")
-#   IDs <- sapply(rings, function(x) slot(x, "ID"))
-#   res <- lapply(rings, function(x) {
-#     Polygons(list(Polygon(x@coords)), ID = x@ID)
-#   })
-#   SpatialPolygonsDataFrame(SpatialPolygons(res), from@data)
-# }
-# 
-# setAs("SpatialRings", "SpatialPoints",
-#       as.SpatialPoints.SpatialRings)
